# coding=utf-8
from __future__ import absolute_import
from .helper import utils
from .helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Bina(Totalvoice):
    
    def __init__(self, cliente):
        super(Bina, self).__init__(cliente)

    def enviar(self, telefone):
        """
        :Descrição:

        Envia um número de telefone para que receba um código via SMS (celular) ou TSS (fixo)

        :Utilização:

        enviar(telefone)

        :Parâmetros:
        
        - telefone:
        Número do telefone que irá receber a Chamada(fixo) ou SMS(móvel) com o código para validação
        """
        host = self.build_host(self.cliente.host, Routes.BINA)
        data = self.__build_bina(telefone)
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def validar(self, codigo, telefone):
        """
        :Descrição:

        Você deve informar o código recebido no celular (SMS) ou telefone (TTS) informados no método POST, para realizarmos a validação

        :Utilização:

        validar(codigo, telefone)

        :Parâmetros:

        - codigo:
        Código que será validado.

        - telefone:
        Telefone que será validado.
        """
        host = self.cliente.host + Routes.BINA
        params = (('codigo', codigo),('telefone', telefone),)
        return self.get_request(host, params)

    def excluir(self, telefone):
        """
        :Descrição:

        Apaga o número de telefone (Bina) cadastrado na Conta

        :Utilização:

        excluir(telefone)

        :Parâmetros:

        - telefone:
        Telefone (bina) que será removido.
        """
        host = self.build_host(self.cliente.host, Routes.BINA, [telefone])
        response = requests.delete(host, headers=utils.build_header(self.cliente.access_token))
        return response.content
    
    def get_relatorio(self):
        """
        :Descrição:
        
        Busca os telefones (Bina) cadastrados na Conta

        :Utilização:

        get_relatorio()  

        """
        host = self.build_host(self.cliente.host, Routes.BINA, ["relatorio"])
        return self.get_request(host)

    def __build_bina(self, telefone):
        data = {}
        data.update({"telefone": telefone})
        return json.dumps(data)



# coding=utf-8
from __future__ import absolute_import
from .helper import utils
from .helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Did(Totalvoice):
    
    def __init__(self, cliente):
        super(Did, self).__init__(cliente)

    def get_my_dids(self):
        """
        :Descrição:

        Função para buscar todos os dids seus dids

        :Utilização:

        get_my_dids()

        """
        host = self.build_host(self.cliente.host, Routes.DID)
        return self.get_request(host)

    def get_estoque(self):
        """
        :Descrição:

        Função para buscar a lista de dids no estoque

        :Utilização:

        get_my_dids()

        """
        host = self.build_host(self.cliente.host, Routes.DID_ESTOQUE)
        return self.get_request(host)

    def compra_estoque(self, did_id):
        """
        :Descrição:

        Essa é uma função que compra um número (did) do estoque

        :Utilização:

        compra_estoque(did_id)

        :Parâmetros:
        
        - did_id:
        ID do did que deseja comprar
        """
        host = self.build_host(self.cliente.host, Routes.DID_ESTOQUE)
        data = {}
        data.update({"did_id": did_id})
        data = json.dumps(data)
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def editar(self, did_id, ura_id=None, ramal_id=None):
        """
        :Descrição:

        Função para editar o seu did.

        :Utilização:

        editar(did_id, ura_id, ramal_id)

        :Parâmetros:
        
        - did_id:
        ID do did que deseja editar.
        
        - ura_id:
        Ura ID para atrlar ao did.

        - ramal_id:
        Ramal ID para atrlar ao did.
        """
        data = {}
        data.update({"did_id": did_id})
        data.update({"ura_id": ura_id})
        data.update({"ramal_id": ramal_id})
        host = self.build_host(self.cliente.host, Routes.DID)
        response = requests.put(host, headers=utils.build_header(self.cliente.access_token), data=json.dumps(data))
        return response.content

    def deletar(self, id):
        """
        :Descrição:

        Função para remover o did da conta.

        :Utilização:

        deletar(id)

        :Parâmetros:

        - id:
        ID do did.
        """
        host = self.build_host(self.cliente.host, Routes.DID, [id])
        response = requests.delete(host, headers=utils.build_header(self.cliente.access_token))
        return response.content

    def get_chamada_recebida(self, id):
        """
        :Descrição:

        Função para buscar as informações de uma chamada recebida.

        :Utilização:

        get_chamada_recebida(id)

        :Parâmetros:

        - id:
        ID da chamada ativa.
        """
        host = self.cliente.host + Routes.DID_CHAMADA + "/" + id
        return self.get_request(host)

    def get_relatorio(self, data_inicio, data_fim, id=None):
        """
        :Descrição:
        
        Função para pegar o relatório de chamadas recebidas.

        :Utilização:

        get_relatorio(data_inicio, data_fim, id)

        :Parâmetros:

        - data_inicio:
        Data início do relatório (2016-03-30T17:15:59-03:00)
        format UTC

        - data_fim:
        Data final do relatório (2016-03-30T17:15:59-03:00)
        format UTC
        
        - id:
        Se preenchido busca os dados daquele número específico.

        """
        host = self.build_host(self.cliente.host, Routes.DID, ["relatorio"])
        if id is not None:
            host = host + id
        params = (('data_inicio', data_inicio),('data_fim', data_fim),)
        return self.get_request(host, params)


# coding=utf-8
from __future__ import absolute_import
from totalvoice.cliente.api.chamada import Chamada
from totalvoice.cliente.api.tts import Tts 
from totalvoice.cliente.api.sms import Sms
from totalvoice.cliente.api.audio import Audio
from totalvoice.cliente.api.conferencia import Conferencia
from totalvoice.cliente.api.minhaconta import MinhaConta
from totalvoice.cliente.api.composto import Composto
from totalvoice.cliente.api.conta import Conta
from totalvoice.cliente.api.bina import Bina
from totalvoice.cliente.api.central.webphone import Webphone
from totalvoice.cliente.api.central.ramal import Ramal
from totalvoice.cliente.api.central.ura import Ura
from totalvoice.cliente.api.did import Did
from totalvoice.cliente.api.fila import Fila


class Api(object):
    
    def __init__(self, cliente):
        self._cliente = cliente
        self._chamada        = None
        self._tts            = None
        self._sms            = None
        self._audio          = None
        self._conferencia    = None
        self._minha_conta    = None
        self._composto       = None
        self._conta          = None
        self._bina           = None
        self._webphone       = None
        self._ramal          = None
        self._ura            = None
        self._did            = None
        self._fila           = None
    
    @property
    def chamada(self):
        """
        :Descrição:
        Acessa Chamada da Totalvoice

        :returns:

        Chamada Totalvoice

        :rtype:

        totalvoice.cliente.api.chamada.Chamada
        """
        if self._chamada is None:
            self._chamada = Chamada(self._cliente)
        return self._chamada
    
    @property
    def tts(self):
        """
        :Descrição:

        Acessa TTS da Totalvoice

        :returns:

        TTS Totalvoice

        :rtype:

        totalvoice.cliente.api.tts.Tts
        """
        if self._tts is None:
            self._tts = Tts(self._cliente)
        return self._tts
    
    @property
    def sms(self):
        """
        :Descrição:

        Acessa SMS da Totalvoice

        :returns:

        SMS Totalvoice

        :rtype:

        totalvoice.cliente.api.sms.Sms
        """
        if self._sms is None:
            self._sms = Sms(self._cliente)
        return self._sms

    @property
    def audio(self):
        """
        :Descrição:

        Acessa Audio da Totalvoice

        :returns:

        Audio Totalvoice

        :rtype:

        totalvoice.cliente.api.audio.Audio
        """
        if self._audio is None:
            self._audio = Audio(self._cliente)
        return self._audio
    
    @property
    def conferencia(self):
        """
        :Descrição:

        Acessa Conferência da Totalvoice

        :returns:

        Conferência Totalvoice

        :rtype:

        totalvoice.cliente.api.conferencia.Conferencia
        """
        if self._conferencia is None:
            self._conferencia = Conferencia(self._cliente)
        return self._conferencia

    @property
    def minha_conta(self):
        """
        :Descrição:

        Acessa Minha Conta da Totalvoice

        :returns:

        MinhaConta Totalvoice

        :rtype:

        totalvoice.cliente.api.minhaconta.MinhaConta
        """
        if self._minha_conta is None:
            self._minha_conta = MinhaConta(self._cliente)
        return self._minha_conta

    @property
    def composto(self):
        """
        :Descrição:

        Acessa Composto da Totalvoice

        :returns:

        Composto Totalvoice

        :rtype:

        totalvoice.cliente.api.composto.Composto
        """
        if self._composto is None:
            self._composto = Composto(self._cliente)
        return self._composto

    @property
    def conta(self):
        """
        :Descrição:

        Acessa Conta da Totalvoice

        :returns:

        Conta Totalvoice

        :rtype:

        totalvoice.cliente.api.conta.Conta
        """
        if self._conta is None:
            self._conta = Conta(self._cliente)
        return self._conta

    @property
    def bina(self):
        """
        :Descrição:

        Acessa Bina da Totalvoice

        :returns:

        Bina Totalvoice

        :rtype:

        totalvoice.cliente.api.bina.Bina
        """
        if self._bina is None:
            self._bina = Bina(self._cliente)
        return self._bina

    @property
    def webphone(self):
        """
        :Descrição:

        Acessa Webphone da Totalvoice

        :returns:

        WEbphone Totalvoice

        :rtype:

        totalvoice.cliente.api.central.webphone.Webphone
        """
        if self._webphone is None:
            self._webphone = Webphone(self._cliente)
        return self._webphone

    @property
    def ura(self):
        """
        :Descrição:

        Acessa Ura da Totalvoice

        :returns:

        Ura Totalvoice

        :rtype:

        totalvoice.cliente.api.central.ura.Ura
        """
        if self._ura is None:
            self._ura = Ura(self._cliente)
        return self._ura

    @property
    def ramal(self):
        """
        :Descrição:

        Acessa Ramal da Totalvoice

        :returns:

        Ramal Totalvoice

        :rtype:

        totalvoice.cliente.api.central.ramal.Ramal
        """
        if self._ramal is None:
            self._ramal = Ramal(self._cliente)
        return self._ramal

    @property
    def did(self):
        """
        :Descrição:

        Gerenciamento de dids

        :returns:

        Did Totalvoice

        :rtype:

        totalvoice.cliente.api.did.Did
        """
        if self._did is None:
            self._did = Did(self._cliente)
        return self._did

    @property
    def fila(self):
        """
        :Descrição:

        Gerenciamento de filas

        :returns:

        Fila Totalvoice

        :rtype:

        totalvoice.cliente.api.fila.Fila
        """
        if self._fila is None:
            self._fila = Fila(self._cliente)
        return self._fila



# coding=utf-8
from __future__ import absolute_import
from .helper import utils
from .helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Tts(Totalvoice):

    def __init__(self, cliente):
        super(Tts, self).__init__(cliente)

    def enviar(self, numero_destino, mensagem, velocidade=None, resposta_usuario=None, tipo_voz=None, bina=None):
        """
        :Descrição:

        Função para enviar TTS (Text-to-speech)

        :Utilização:

        enviar(self, numero_destino, mensagem, velocidade, resposta_usuario, tipo_voz, bina)

        :Parâmetros:
        
        - numero_destino:
        Número do telefone que irá receber a mensagem, formato DDD + Número exemplo: 4832830151.

        - mensagem:
        Mensagem que será lida para o destinatário.

        - valocidade
        De -10 a 10. Onde -10=muito lento, 0=normal e 10=muito rápido.

        - resposta_usuario:
        Aguardar uma resposta do destinatário. true ou false.

        - tipo_voz:
        Informe a sigla do idioma concatenado ao nome do personagem que vai falar. Ex: br-Ricardo, br-Vitoria.

        - bina:
        Número e telefone que aparecerá no identificador de quem receber a chamada, formato DDD + Número exemplo: 4832830151.
        """
        host = self.build_host(self.cliente.host, Routes.TTS)
        data = self.__build_tts(numero_destino, mensagem, velocidade, resposta_usuario, tipo_voz, bina)
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def get_by_id(self, id):
        """
        :Descrição:

        Função para buscar informações de TTS e respostas.

        :Utilização:

        get_by_id(id)

        :Parâmetros:

        - id:
        ID do tts.
        """
        host = self.build_host(self.cliente.host, Routes.TTS, [id])
        return self.get_request(host)

    def get_relatorio(self, data_inicio, data_fim):
        """
        :Descrição:
        
        Função para pegar o relatório de tts.

        :Utilização:

        get_relatorio(data_inicio, data_fim)

        :Parâmetros:

        - data_inicio:
        Data início do relatório (2016-03-30T17:15:59-03:00)
        format UTC

        - data_fim:
        Data final do relatório (2016-03-30T17:15:59-03:00)
        format UTC    

        """
        host = self.build_host(self.cliente.host, Routes.TTS, ["relatorio"])
        params = (('data_inicio', data_inicio),('data_fim', data_fim),)
        return self.get_request(host, params)

    def __build_tts(self, numero_destino, mensagem, velocidade, resposta_usuario, tipo_voz, bina):
        data = {}
        data.update({"numero_destino": numero_destino})
        data.update({"mensagem": mensagem})
        data.update({"velocidade": velocidade})
        data.update({"resposta_usuario": resposta_usuario})
        data.update({"tipo_voz": tipo_voz})
        data.update({"bina": bina})
        return json.dumps(data)



# coding=utf-8
from __future__ import absolute_import
from .helper import utils
from .helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class MinhaConta(Totalvoice):

    def __init__(self, cliente):
        super(MinhaConta, self).__init__(cliente)

    def get_saldo(self):
        """
        :Descrição:

        Função para buscar saldo da sua conta.

        :Utilização:

        get_saldo()
        """
        host = self.build_host(self.cliente.host, Routes.SALDO)
        return self.get_request(host)

    def get_conta(self):
        """
        :Descrição:

        Função para buscar a sua conta.

        :Utilização:

        get_conta()
        """
        host = self.build_host(self.cliente.host, Routes.CONTA)
        return self.get_request(host)

    def editar_conta(self, nome, login, senha, cpf_cnpj=None, preco_fixo=None, preco_cel=None, preco_ramal=None, email_financeiro=None, nome_fantasia=None):
        """
        :Descrição:

        Função para editar a sua conta.

        :Utilização:

        editar_conta()

        :Parâmetros:
        
        - nome:
        Nome da conta.

        - login:
        Login da conta.

        - senha:
        Senha da conta;

        - cpf_cnpj:
        CPF ou CNPJ da conta.

        - preco_fixo:
        Preço de chamadas para fixo da conta.

        - preco_cel:
        Preço de chamadas para celulares da conta.

        - preco_ramal:
        Preço para ramais da conta.

        - email_financeiro:
        E-mail responsável pelo financeiro da conta.

        - nome_fantasia
        Nome fantasia da conta
        """
        host = self.build_host(self.cliente.host, Routes.CONTA)
        data = self.__build_conta(nome, login, senha, cpf_cnpj, preco_fixo, preco_cel, preco_ramal, email_financeiro, nome_fantasia)
        response = requests.put(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def get_recargas(self):
        """
        :Descrição:

        Função para as recargas da conta.

        :Utilização:

        get_recargas()
        """
        host = self.build_host(self.cliente.host, Routes.CONTA_RECARGAS)
        return self.get_request(host)

    def get_url_recarga(self, url_retorno):
        """
        :Descrição:

        Função para obter a url de recarga da conta.

        :Utilização:

        get_url_recarga()

        :Parâmetros:

        - url_retorno:
        URL para retorno depois da recarga ou ao cancelar.
        """
        data = {}
        data.update({"url_retorno": url_retorno})
        host = self.build_host(self.cliente.host, Routes.CONTA_URL_RECARGA, data=data)
        return self.get_request(host)

    def get_webhook(self):
        """
        :Descrição:

        Função para obter a lista webhook da conta.

        :Utilização:

        get_webhook()
        """
        host = self.build_host(self.cliente.host, Routes.WEBHOOK)
        return self.get_request(host)

    def delete_webhook(self, nome_webhook):
        """
        :Descrição:

        Função para deletar um webhook.

        :Utilização:

        get_webhook(nome_webhook)

        :Parâmetros:
        
        - nome_webhook:
        Nome do webhook.
        """
        host = self.build_host(self.cliente.host, Routes.WEBHOOK, [nome_webhook])
        response = requests.delete(host, headers=utils.build_header(self.cliente.access_token), data=None)
        return response.content

    def editar_webhook(self, nome_webhook, url):
        """
        :Descrição:

        Função para deletar um webhook.

        :Utilização:

        editar_webhook(nome_webhook, url)

        :Parâmetros:
        
        - nome_webhook:
        Nome do webhook.

        - url:
        Url do webhook
        """
        host = self.build_host(self.cliente.host, Routes.WEBHOOK, [nome_webhook])
        data = {}
        data.update({"url" : url})
        response = requests.put(host, headers=utils.build_header(self.cliente.access_token), data=json.dumps(data))
        return response.content


    def __build_conta(self, nome, login, senha, cpf_cnpj, preco_fixo, preco_cel, preco_ramal, email_financeiro, nome_fantasia):
        data = {}
        data.update({"nome": nome})
        data.update({"login": login})
        data.update({"senha": senha})
        data.update({"cpf_cnpj": cpf_cnpj})
        data.update({"preco_fixo": preco_fixo})
        data.update({"preco_cel": preco_cel})
        data.update({"preco_ramal": preco_ramal})
        data.update({"email_financeiro": email_financeiro})
        data.update({"nome_fantasia": nome_fantasia})
        return json.dumps(data)



# coding=utf-8
from __future__ import absolute_import
from .helper import utils
from .helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Fila(Totalvoice):
    
    def __init__(self, cliente):
        super(Fila, self).__init__(cliente)

    def get_fila(self, id):
        """
        :Descrição:

        Função para buscar as informações de uma fila

        :Utilização:

        get_fila(id)

        :Parâmetros:

        - id:
        ID da fila. 

        """
        host = self.build_host(self.cliente.host, Routes.FILA, [id])
        return self.get_request(host)

    def criar(self, nome, estrategia_ring, timeout_ring=None):
        """
        :Descrição:

        Função para criar uma fila

        :Utilização:

        criar(nome, estrategia_ring, timeout_ring)

        :Parâmetros:
        
        - nome:
        Nome da fila a ser criada

        - estrategia_ring:
        Multiplo para tocar todos ao mesmo tempo ou Distribuidor para tocar um ramal por vez.

        - timeout_ring
        Número em segundos para derrubar a chamada da fila.

        """
        host = self.build_host(self.cliente.host, Routes.FILA)
        data = self.__build_fila(nome, estrategia_ring, timeout_ring)
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def add_ramal(self, id_fila, ramal_id):
        """
        :Descrição:

        Adiciona um ramal na fila

        :Utilização:

        add_ramal(id_fila, ramal_id)

        :Parâmetros:
        
        - id_fila:
        ID da fila

        - ramal_id:
        ID do ramal a ser adicionado na fila

        """
        host = self.build_host(self.cliente.host, Routes.FILA, [id_fila])
        data = {"ramal_id": ramal_id}
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def editar(self, id, nome=None, estrategia_ring=None, timeout_ring=None):
        """
        :Descrição:

        Função para a fila.

        :Utilização:

        editar(nome, estrategia_ring, timeout_ring)

        :Parâmetros:
        
        - id:
        ID da fila a ser editada
        
        - nome:
        Nome da fila a ser criada

        - estrategia_ring:
        Multiplo para tocar todos ao mesmo tempo ou Distribuidor para tocar um ramal por vez.

        - timeout_ring
        Número em segundos para derrubar a chamada da fila.
        """
        dados = self.__build_fila(nome, estrategia_ring, timeout_ring)
        host = self.build_host(self.cliente.host, Routes.FILA, [id])
        response = requests.put(host, headers=utils.build_header(self.cliente.access_token), data=json.dumps(dados))
        return response.content

    def deleta_ramal(self, id, ramal_id):
        """
        :Descrição:

        Deleta ramal de uma fila

        :Utilização:

        deleta_ramal(id, ramal_id)

        :Parâmetros:

        - id:
        ID da fila.

        - ramal_id:
        ID do ramal.
        """
        host = self.build_host(self.cliente.host, Routes.FILA, [id], [ramal_id])
        response = requests.delete(host, headers=utils.build_header(self.cliente.access_token))
        return response.content

    def get_fila_ramal(self, id, ramal_id):
        """
        :Descrição:

        Função para buscar as informações de uma fila e o ramal

        :Utilização:

        get_fila(id, ramal_id)

        :Parâmetros:

        - id:
        ID da fila.

        - ramal_id:
        ID do ramal.

        """
        host = self.build_host(self.cliente.host, Routes.FILA, [id], [ramal_id])
        return self.get_request(host)
        
    def __build_fila(self, nome, estrategia_ring, timeout_ring):
        data = {}
        data.update({"nome": nome})
        data.update({"estrategia_ring": estrategia_ring})
        data.update({"timeout_ring": timeout_ring})
        return json.dumps(data)


from __future__ import absolute_import
import requests
from .helper import utils
class Totalvoice(object):

    def __init__(self, cliente):
        self.cliente = cliente
    
    def enviar(self, *args):
        raise NotImplementedError
    
    def get_by_id(self, id):
        raise NotImplementedError
    
    def editar(self, *args):
        raise NotImplementedError
    
    def get_relatorio(self, *args):
        raise NotImplementedError
        
    def deletar(self, id):
        raise NotImplementedError

    def get_request(self, host, params = None):
        if params != None:
            response = requests.get(host, headers=utils.build_header(self.cliente.access_token), params=params)
        else:
            response = requests.get(host, headers=utils.build_header(self.cliente.access_token))
        return response.content

    def build_host(self, host, route, values=None):
        host += route
        if values is not None:
            for val in values:
                host +=  "/" + val
        return host
        


# coding=utf-8

from totalvoice.cliente.api.helper import utils
from totalvoice.cliente.api.helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Ura(Totalvoice):

    def __init__(self, cliente):
        super(Ura, self).__init__(cliente)

    def criar(self, nome, dados):
        """
        :Descrição:

        Função para criar uma ura.

        :Utilização:

        criar_ura()

        :Parâmetros:
        
        - nome:
        Nome para identificação

        - dados:
        Array de objetos com acao, opcao, menu e acao_dados. opção null = default. menu null = menu 1. Ação pode ser tts, audio, fila, transferir.
        """
        host = self.cliente.host + Routes.URA
        data = self.__build_ura(nome, dados)
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def deletar(self, id):
        """
        :Descrição:

        Função para deletar um ramal.

        :Utilização:

        deletar(id)

        :Parâmetros:

        - id:
        ID da ura.
        """
        host = self.build_host(self.cliente.host, Routes.URA, [id])
        response = requests.delete(host, headers=utils.build_header(self.cliente.access_token))
        return response.content

    def editar(self, id, nome, dados):
        """
        :Descrição:

        Função para editar o ramal.

        :Utilização:

        editar(id, nome, dados)

        :Parâmetros:
        - id:
        ID da ura.

        - nome:
        Nome para identificação

        - dados:
        Array de objetos com acao, opcao, menu e acao_dados. opção null = default. menu null = menu 1. Ação pode ser tts, audio, fila, transferir.  
        """
        host = self.build_host(self.cliente.host, Routes.URA, [id])
        data = self.__build_ura(nome, dados)
        response = requests.put(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def __build_ura(self, nome, dados):
        data = {}
        data.update({"nome": nome})
        data.update({"dados": dados})
        return json.dumps(data)



# coding=utf-8
from __future__ import absolute_import
from .helper import utils
from .helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Audio(Totalvoice):
    
    def __init__(self, cliente):
        super(Audio, self).__init__(cliente)

    def enviar(self, numero_destino, url_audio, resposta_usuario=None, bina=None, gravar_audio=None):
        """
        :Descrição:

        Essa é uma função para enviar um áudio para um número destino.

        :Utilização:

        enviar(numero_destino, url_audio, resposta_usuario, bina)

        :Parâmetros:
        
        - numero_destino:
        Número do telefone destino.

        - url_audio:
        URL do áudio a ser enviado.

        - resposta_usuario:
        Booleano que informa se o usuário pode responder o áudio.

        - bina:
        Número de bina para a chamada de áudio.
        """
        host = self.build_host(self.cliente.host, Routes.AUDIO)
        data = self.__build_audio(numero_destino, url_audio, resposta_usuario, bina, gravar_audio)
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def get_by_id(self, id):
        """
        :Descrição:

        Função para buscar as informações de um audio.

        :Utilização:

        get_by_id(id)

        :Parâmetros:

        - id:
        ID do audio.
        """
        host = self.cliente.host + Routes.AUDIO + "/" + id
        return self.get_request(host)
    
    def get_relatorio(self, data_inicio, data_fim):
        """
        :Descrição:
        
        Função para pegar o relatório de áudios.

        :Utilização:

        get_relatorio(data_inicio, data_fim)

        :Parâmetros:

        - data_inicio:
        Data início do relatório (2016-03-30T17:15:59-03:00)
        format UTC

        - data_fim:
        Data final do relatório (2016-03-30T17:15:59-03:00)
        format UTC    

        """
        host = self.build_host(self.cliente.host, Routes.AUDIO, ["relatorio"])
        params = (('data_inicio', data_inicio),('data_fim', data_fim),)
        return self.get_request(host, params)

    def __build_audio(self, numero_destino, url_audio, resposta_usuario=None, bina=None, gravar_audio=None):
        data = {}
        data.update({"numero_destino": numero_destino})
        data.update({"url_audio": url_audio})
        data.update({"resposta_usuario": resposta_usuario})
        data.update({"bina": bina})
        data.update({"gravar_audio": gravar_audio})
        return json.dumps(data)



# coding=utf-8

from totalvoice.cliente.api.helper import utils
from totalvoice.cliente.api.helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Webphone(Totalvoice):

    def __init__(self, cliente):
        super(Webphone, self).__init__(cliente)

    def get_webphone(self, tipo="floating", id_ramal=None, ramal=None, ligar_para=None, fechar_fim=None):
        """
        :Descrição:
        
        Função para pegar o relatório de ramais.

        :Utilização:

        get_webphone()
        
        :Parâmetros:
        - tipo:
        Embedded = embutido no site, floating = popup, hidden = sem interface e com funcoes de callback. veja documentacao de exemplo no blog.

        - id_ramal:
        ID do ramal para pré-configurar o widget

        - ramal:
        Número do ramal para pré-configurar o widget.

        - ligar_para:
        Abrir o webphone ligando para o número, formato DDD + Número exemplo: 4832830151.

        - fechar_fim:
        Fechar a janela do webphone quando a chamada for encerrada?
        """
        host = self.build_host(self.cliente.host, Routes.WEBPHONE)
        params = (('tipo', tipo),('id_ramal', id_ramal), ('ramal', ramal), ('ligar_para', ligar_para), ('fechar_fim', fechar_fim))
        return self.get_request(host, params)



# coding=utf-8
from __future__ import absolute_import
from .helper import utils
from .helper.routes import Routes
from totalvoice.cliente.api.totalvoice import Totalvoice
import json, requests


class Composto(Totalvoice):
    
    def __init__(self, cliente):
        super(Composto, self).__init__(cliente)

    def enviar(self, numero_destino, dados, bina=None, tags=None):
        """
        :Descrição:

        Essa é uma função para enviar um composto de dados para um número destino.

        :Utilização:

        enviar(numero_destino, dados, bina, tags)

        :Parâmetros:
        
        - numero_destino:
        Número do telefone destino.

        - dados:
        Array de objetos com acao e acao_dados , podendo ser TTS, Audio ou Transferir cada um deles. 
        O campo opcao é opcional, se configurado, só aciona a ação se a opção tiver sido digitada - DTMF.

        - bina:
        Número e telefone que aparecerá no identificador de quem receber a chamada, formato 
        DDD + Número exemplo: 4832830151

        - tags:
        Tags para uso geral
        """
        host = self.build_host(self.cliente.host, Routes.COMPOSTO)
        data = self.__build_composto(numero_destino, dados, bina, tags)
        response = requests.post(host, headers=utils.build_header(self.cliente.access_token), data=data)
        return response.content

    def get_by_id(self, id):
        """
        :Descrição:

        Função para buscar as informações de um composto enviado.

        :Utilização:

        get_by_id(id)

        :Parâmetros:

        - id:
        ID do composto.
        """
        host = self.cliente.host + Routes.COMPOSTO + "/" + id
        return self.get_request(host)
    
    def get_relatorio(self, data_inicio, data_fim):
        """
        :Descrição:
        
        Função para pegar o relatório de compostos.

        :Utilização:

        get_relatorio(data_inicio, data_fim)

        :Parâmetros:

        - data_inicio:
        Data início do relatório (2016-03-30T17:15:59-03:00)
        format UTC

        - data_fim:
        Data final do relatório (2016-03-30T17:15:59-03:00)
        format UTC    

        """
        host = self.build_host(self.cliente.host, Routes.COMPOSTO, ["relatorio"])
        params = (('data_inicio', data_inicio),('data_fim', data_fim),)
        return self.get_request(host, params)

    def __build_composto(self, numero_destino, dados, bina, tags):
        data = {}
        data.update({"numero_destino": numero_destino})
        data.update({"dados": dados})
        data.update({"bina": bina})
        data.update({"tags": tags})
        return json.dumps(data)



# coding=UTF-8
"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
try:
    with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
        long_description = f.read()
except:
    long_description = ''

setup(
    # Ver PEP 426 (name)
    # Iniciar ou terminar com letra ou número
    name='totalvoice',

    # Ver PEP 440
    # O formato pode ser assim:

    # 1.2.0.dev1  # Development release
    # 1.2.0a1     Alpha Release
    # 1.2.0b1     Beta Release
    # 1.2.0rc1    Release Candidate
    # 1.2.0       Final Release
    # 1.2.0.post1 Post Release
    # 15.10       Date based release
    # 23          Serial release

    version='1.3.3',

    
    description='Biblioteca da Totalvoice em python',
    long_description=long_description,

    # A página do projeto
    url='https://github.com/totalvoice/totalvoice-python',

    # Detalhes do Autor
    author=u'Carlos Henrique dos Santos',
    author_email='carlos@totalvoice.com.br',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Education :: Testing',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],

    # What does your project relate to?
    keywords='api rest totalvoice telefonia ligação',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    #install_requires=['sh>=1.11'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #     'data': ['dados.json'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('python101', ['data/dados.json'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
        # 'console_scripts': [
            # 'sample=sample:main',
        # ],
    # },
)


# coding=utf-8
from __future__ import absolute_import
from totalvoice.cliente.api.helper import utils

class Cliente(object):
      
    def __init__(self, access_token, host):
        self.access_token = access_token
        self.host = utils.build_host(host)
        self._api = None

    @property
    def api(self):
        """
        :Descrição:

        Acessa a API da Totalvoice

        :returns:

        API Totalvoice

        :rtype:

        totalvoice.cliente.api.Api
        """
        if self._api is None:
            from totalvoice.cliente.api import Api
            self._api = Api(self)
        return self._api

    @property
    def chamada(self):
        """
        :Descrição:

        Acessa Chamada da Totalvoice

        :returns:

        Chamada Totalvoice

        :rtype:

        totalvoice.cliente.api.chamada.Chamada
        """
        return self.api.chamada
    
    @property
    def tts(self):
        """
        :Descrição:

        Acessa TTS da Totalvoice

        :returns:

        TTS Totalvoice

        :rtype:

        totalvoice.cliente.api.tts.Tts
        """
        return self.api.tts

    @property
    def audio(self):
        """
        :Descrição:

        Acessa Audio da Totalvoice

        :returns:

        Audio Totalvoice

        :rtype:

        totalvoice.cliente.api.audio.Audio
        """
        return self.api.audio

    @property
    def sms(self):
        """
        :Descrição:

        Acessa SMS da Totalvoice

        :returns:

        SMS Totalvoice

        :rtype:

        totalvoice.cliente.api.sms.Sms
        """
        return self.api.sms
    
    @property
    def conferencia(self):
        """
        :Descrição:

        Acessa Conferência da Totalvoice

        :returns:

        Conferência Totalvoice

        :rtype:

        totalvoice.cliente.api.conferencia.Conferencia
        """
        return self.api.conferencia

    @property
    def minha_conta(self):
        """
        :Descrição:

        Acessa Minha Conta da Totalvoice

        :returns:

        MinhaConta Totalvoice

        :rtype:

        totalvoice.cliente.api.minhaconta.MinhaConta
        """
        return self.api.minha_conta

    @property
    def composto(self):
        """
        :Descrição:

        Acessa Composto da Totalvoice

        :returns:

        Composto Totalvoice

        :rtype:

        totalvoice.cliente.api.composto.Composto
        """
        return self.api.composto

    @property
    def conta(self):
        """
        :Descrição:

        Acessa Conta da Totalvoice

        :returns:

        Conta Totalvoice

        :rtype:

        totalvoice.cliente.api.conta.Conta
        """
        return self.api.conta

    @property
    def bina(self):
        """
        :Descrição:

        Acessa Bina da Totalvoice

        :returns:

        Bina Totalvoice

        :rtype:

        totalvoice.cliente.api.bina.Bina
        """
        return self.api.bina

    @property
    def ramal(self):
        """
        :Descrição:

        Acessa Ramal da Totalvoice

        :returns:

        Ramal Totalvoice

        :rtype:

        totalvoice.cliente.api.central.ramal.Ramal
        """
        return self.api.ramal

    @property
    def ura(self):
        """
        :Descrição:

        Acessa Ura da Totalvoice

        :returns:

        Ura Totalvoice

        :rtype:

        totalvoice.cliente.api.central.ura.Ura
        """
        return self.api.ura

    @property
    def webphone(self):
        """
        :Descrição:

        Acessa Webphone da Totalvoice

        :returns:

        Webphone Totalvoice

        :rtype:

        totalvoice.cliente.api.central.webphone.Webphone
        """
        return self.api.webphone

    @property
    def did(self):
        """
        :Descrição:

        Gerenciamento de Dids

        :returns:

        Did Totalvoice

        :rtype:

        totalvoice.cliente.api.did.Did
        """
        return self.api.did

    @property
    def fila(self):
        """
        :Descrição:

        Gerenciamento de Fila

        :returns:

        Fila Totalvoice

        :rtype:

        totalvoice.cliente.api.fila.Fila
        """
        return self.api.fila
